@@ -29,11 +29,6 @@ class showPOI(ranaModule):
     ranaModule.__init__(self, m, d)
     self.scroll = 0
     
-  def update(self):
-    # Get and set functions are used to access global data
-    self.set('num_updates', self.get('num_updates', 0) + 1)
-    #print "Updated %d times" % (self.get('num_updates'))
-    pass
   
   def drawMenu(self, cr, menuName):
     if menuName == 'showPOI' or menuName == 'showPOIDetail' or menuName == 'showPOIRoute':
